@@ -14,11 +14,11 @@ Sub::Exporter - a sophisticated exporter for custom-built routines
 
 =head1 VERSION
 
-version 0.977_01
+version 0.977_02
 
 =cut
 
-our $VERSION = '0.977_01';
+our $VERSION = '0.977_02';
 
 =head1 SYNOPSIS
 
@@ -176,9 +176,29 @@ The following keys are valid in C<%config>:
   groups  - a list of groups to provide for exporting; each must be followed by
             either (a) a list of exports, possibly with arguments for each
             export, or (b) a generator
+
   collectors - a list of names into which values are collected for use in
                routine generation; each name may be followed by a validator
 
+In addition to the basic options above, a few more advanced options may be
+passed:
+
+  into_level - how far up the caller stack to look for a target (default 0)
+  into       - an explicit target (package) into which to export routines
+
+In other words: Sub::Exporter installs a C<import> routine which, when called,
+exports routines to the calling namespace.  The C<into> and C<into_level>
+options change where those exported routines are installed.
+
+  generator  - a callback used to produce the code that will be installed
+               default: Sub::Exporter::default_generator
+
+  installer  - a callback used to install the code produced by the generator
+               default: Sub::Exporter::default_installer
+
+For information on how these callbacks are used, see the documentation for
+C<L</default_generator>> and C<L</default_installer>>.
+
 =head2 Export Configuration
 
 The C<exports> list may be provided as an array reference or a hash reference.
@@ -363,11 +383,13 @@ first argument, in a hashref.
 
 These options are:
 
-  into_level - how far up the caller stack to look for a target (default 0)
-  into       - an explicit target (package) into which to export routines
+  into_level
+  into
+  generator
+  installer
 
-Providing both C<into_level> and C<into> will cause an exception to be
-thrown.
+These override the same-named configuration options described in L</EXPORTER
+CONFIGURATION>.
 
 =cut
 
@@ -550,9 +572,6 @@ The exporter is built by C<L</build_exporter>>.
 
 =cut
 
-# \%special is for experimental options that may or may not be kept around and,
-# probably, moved to \%config.  These are also passed along to build_exporter.
-
 sub setup_exporter {
   my ($config)  = @_;
 
@@ -599,7 +618,8 @@ my %valid_config_key;
 BEGIN {
   %valid_config_key =
     map { $_ => 1 }
-    qw(collectors exporter generator exports groups into into_level)
+    qw(collectors installer generator exports groups into into_level),
+    qw(exporter), # deprecated
 }
 
 sub _rewrite_build_config {
@@ -609,6 +629,15 @@ sub _rewrite_build_config {
     Carp::croak "unknown options (@keys) passed to Sub::Exporter";
   }
 
+  Carp::croak q(into and into_level may not both be supplied to exporter)
+    if exists $config->{into} and exists $config->{into_level};
+
+  # XXX: Remove after deprecation period.
+  if ($config->{exporter}) {
+    Carp::cluck "'exporter' argument to build_exporter is deprecated. Use 'installer' instead; the semantics are identical.";
+    $config->{installer} = delete $config->{exporter};
+  }
+
   Carp::croak q(into and into_level may not both be supplied to exporter)
     if exists $config->{into} and exists $config->{into_level};
 
@@ -640,6 +669,9 @@ sub _rewrite_build_config {
 
   # by default, build an all-inclusive 'all' group
   $config->{groups}{all} ||= [ keys %{ $config->{exports} } ];
+
+  $config->{generator} ||= \&default_generator;
+  $config->{installer} ||= \&default_installer;
 }
 
 sub build_exporter {
@@ -655,6 +687,11 @@ sub build_exporter {
     Carp::croak q(into and into_level may not both be supplied to exporter)
       if exists $special->{into} and exists $special->{into_level};
 
+    if ($special->{exporter}) {
+      Carp::cluck "'exporter' special import argument is deprecated. Use 'installer' instead; the semantics are identical.";
+      $special->{installer} = delete $special->{exporter};
+    }
+
     my $into
       = defined $special->{into}       ? delete $special->{into}
       : defined $special->{into_level} ? caller(delete $special->{into_level})
@@ -662,13 +699,8 @@ sub build_exporter {
       : defined $config->{into_level}  ? caller($config->{into_level})
       :                                  caller(0);
 
-    my $exporter = delete $special->{exporter}
-                || $config->{exporter}
-                || \&default_exporter;
-
-    my $generator = delete $special->{generator}
-                 || $config->{generator}
-                 || \&default_generator;
+    my $generator = delete $special->{generator} || $config->{generator};
+    my $installer = delete $special->{installer} || $config->{installer};
 
     # this builds a AOA, where the inner arrays are [ name => value_ref ]
     my $import_args = Data::OptList::mkopt([ @_ ]);
@@ -687,8 +719,8 @@ sub build_exporter {
         col       => $collection,
         config    => $config,
         into      => $into,
-        exporter  => $exporter,
         generator => $generator,
+        installer => $installer,
       },
       $to_import,
     );
@@ -735,7 +767,7 @@ sub _do_import {
     push @todo, $as, $code;
   }
 
-  $arg->{exporter}->(
+  $arg->{installer}->(
     {
       class => $arg->{class},
       into  => $arg->{into},
@@ -745,58 +777,6 @@ sub _do_import {
   );
 }
 
-# XXX: Consider implementing a _export_args routine that takes the arguments to
-# _export and returns a hash of named params.  This lets other people write
-# exporters without tying me down to one set of @_ contents.  Maybe that's
-# premature guarantee, though, unless I guarantee that @_ will never get
-# /smaller/.
-
-=head2 default_exporter
-
-This is Sub::Exporter's default exporter.  It does what Sub::Exporter promises:
-it installs code into the target package.
-
-B<Warning!>  Its interface isn't really stable yet, so don't rely on it.  It's
-only named here so that you can pass it in to the exporter builder.  It will
-have a stable interface in the future so that it may be more easily replaced.
-
-
-  default_exporter(\%arg, \@to_export);
-
-Passed arguments are:
-
-  into - the package into which exports should be delivered
-
-C<@to_export> is a list of name/value pairs.  The default exporter assigns code
-(the values) to named slots (the names) in the given package.  If the name is a
-scalar reference, the scalar reference is made to point to the code reference
-instead.
-
-=cut
-
-sub default_exporter {
-  my ($arg, $to_export) = @_;
-
-  for (my $i = 0; $i < @$to_export; $i += 2) {
-    my ($as, $code) = @$to_export[ $i, $i+1 ];
-
-    # Allow as isa ARRAY to push onto an array?
-    # Allow into isa HASH to install name=>code into hash?
-
-    if (ref $as eq 'SCALAR') {
-      $$as = $code;
-    } elsif (ref $as) {
-      Carp::croak "invalid reference type for $as: " . ref $as;
-    } else {
-      Sub::Install::reinstall_sub({
-        code => $code,
-        into => $arg->{into},
-        as   => $as
-      });
-    }
-  }
-}
-
 ## Cute idea, possibly for future use: also supply an "unimport" for:
 ## no Module::Whatever qw(arg arg arg);
 # sub _unexport {
@@ -818,10 +798,6 @@ This is Sub::Exporter's default generator.  It takes bits of configuration that
 have been gathered during the import and turns them into a coderef that can be
 installed.
 
-B<Warning!>  Its interface isn't really stable yet, so don't rely on it.  It's
-only named here so that you can pass it in to the exporter builder.  It will
-have a stable interface in the future so that it may be more easily replaced.
-
   my $code = default_generator(\%arg);
 
 Passed arguments are:
@@ -856,6 +832,52 @@ sub default_generator {
   return $class->$$generator($name, $arg->{arg}, $arg->{col});
 }
 
+=head2 default_installer
+
+This is Sub::Exporter's default installer.  It does what Sub::Exporter
+promises: it installs code into the target package.
+
+  default_installer(\%arg, \@to_export);
+
+Passed arguments are:
+
+  into - the package into which exports should be delivered
+
+C<@to_export> is a list of name/value pairs.  The default exporter assigns code
+(the values) to named slots (the names) in the given package.  If the name is a
+scalar reference, the scalar reference is made to point to the code reference
+instead.
+
+=cut
+
+sub default_installer {
+  my ($arg, $to_export) = @_;
+
+  for (my $i = 0; $i < @$to_export; $i += 2) {
+    my ($as, $code) = @$to_export[ $i, $i+1 ];
+
+    # Allow as isa ARRAY to push onto an array?
+    # Allow into isa HASH to install name=>code into hash?
+
+    if (ref $as eq 'SCALAR') {
+      $$as = $code;
+    } elsif (ref $as) {
+      Carp::croak "invalid reference type for $as: " . ref $as;
+    } else {
+      Sub::Install::reinstall_sub({
+        code => $code,
+        into => $arg->{into},
+        as   => $as
+      });
+    }
+  }
+}
+
+sub default_exporter {
+  Carp::croak "default_exporter is deprecated; call default_installer instead; the semantics are identical";
+  goto &default_installer;
+}
+
 =head1 EXPORTS
 
 Sub::Exporter also offers its own exports: the C<setup_exporter> and
